
# rattail-nationbuilder

Rattail is a retail software framework, released under the GNU General
Public License.

This package contains software interfaces for
[NationBuilder](https://nationbuilder.com/).

Please see the [Rattail Project](https://rattailproject.org/)
for more information.
